// ======================================================================
//
// gl_abstract.cpp
// jeff grills
//
// copyright 1998 origin systems inc
//
// ======================================================================

#include "first.h"
#include "gl_abstract.h"

#include "gl_init.h"
#include "gl.def"

// ======================================================================

int                    GL_abstract::width;
int                    GL_abstract::height;
int                    GL_abstract::depth;

const StaticMaterial  *GL_abstract::backgroundMaterial;

const ClipInfo       **GL_abstract::clipInfo;

char                  *GL_abstract::screenShotName;

// ======================================================================

GL_abstract::GL_abstract(void)
{
	width      = 0;
	height     = 0;
	depth      = 0;

	clipInfo   = NULL;

	backgroundMaterial = NULL;
	screenShotName = NULL;

	submitPointListFunction     = defaultSubmitFunction;
	submitLineListFunction      = defaultSubmitFunction;
	submitLineStripFunction     = defaultSubmitFunction;
	submitTriangleListFunction  = defaultSubmitFunction;
	submitTriangleStripFunction = defaultSubmitFunction;
	submitTriangleFanFunction   = defaultSubmitFunction;
}

// ----------------------------------------------------------------------

GL_abstract::~GL_abstract(void)
{
}

// ----------------------------------------------------------------------

void GL_abstract::defaultSubmitFunction(const TVertex *, int )
{
	DEBUG_FATAL(true, ("GL_abstract::defaultSubmitFunction called"));
}

// ----------------------------------------------------------------------

bool GL_abstract::init(const GL_input *input, GL_output *output)
{
	width    = input->width;
	height   = input->height;
	depth    = input->depth;

	clipInfo = input->clipInfo;

	output->useSuperDetailFlag = false;
	output->lightingRGB = false;
	output->translucency = false;
	output->fog = false;
	output->bilinearFiltering = false;

	output->warningOneMegVideoCard = false;
	output->warningBackBufferInSystemRam = false;
	output->warningBankSwitched = false;

	output->textureMemory = -1;

	return true;
}

// ----------------------------------------------------------------------

void GL_abstract::debugDump(void)
{
}

// ----------------------------------------------------------------------

void GL_abstract::setBackgroundMaterial(const StaticMaterial *material)
{
	backgroundMaterial = material;
}

// ----------------------------------------------------------------------

void GL_abstract::getInformation(Information *information)
{
	memset(information, 0, sizeof(*information));
	information->versionMajor = MAJOR;
}

// ----------------------------------------------------------------------

void GL_abstract::setDrawWindow(HWND)
{
	DEBUG_FATAL(true, ("Gl_abstract::setDrawWindow not supported in this rasterizer"));
}

// ----------------------------------------------------------------------

void GL_abstract::screenShot(const char *filename)
{
	screenShotName = MEM_OWN(strdup(filename));
}

// ----------------------------------------------------------------------

void GL_abstract::movie(const uv_instance *)
{
}

// ----------------------------------------------------------------------

bool GL_abstract::specialEffect(int, void *)
{
	return false;
}

// ======================================================================
